#[repr(u8)]pub enum Pcfg1Onechannel {
STEREO = 0,
SINGLE = 1,
}Variants
STEREO = 0
I2S data for this channel pair is treated as left and right channels.
SINGLE = 1
I2S data for this channel pair is treated as a single channel, functionally the left channel for this pair.
Implementations